Home
last modified time | relevance | path

Searched refs:fun2 (Results 1 – 25 of 74) sorted by relevance

123

/llvm-project-15.0.7/clang/test/SemaCXX/
H A Dwarn-tautological-compare.cpp66 int fun2();
76 (void)CallFunction(fun2); in ignore()
82 if (fun2 == 0) {} in test()
96 if (nullptr != fun2) {} in test()
H A Dmember-expr.cpp136 S fun2(); // expected-note{{possible target for call}}
137 S fun2(int i); // expected-note{{possible target for call}}
139 …return fun2.x; // expected-error{{reference to overloaded function could not be resolved; did you … in g2()
164 Vec *fun2();
165 …int test2() { return fun2->size(); } // expected-error {{base of member reference is a function; p… in test2()
/llvm-project-15.0.7/llvm/test/tools/llvm-split/
H A Dscc-comdat.ll9 ; CHECK0: declare dso_local i32 @fun2
13 ; CHECK1: define internal i32 @fun2
23 define internal i32 @fun2() section ".text.funs" comdat($fun) {
/llvm-project-15.0.7/llvm/test/CodeGen/SystemZ/
H A Dvec-perm-14.ll66 define <4 x i8> @fun2(<2 x i8> %arg) {
85 ; CHECK-NEXT: .globl fun2
87 ; CHECK-NEXT: .type fun2,@function
88 ; CHECK-NEXT:fun2: # @fun2
H A Dfp-conv-18.ll7 ; CHECK-LABEL: fun2:
23 define void @fun2() #0 {
/llvm-project-15.0.7/llvm/test/LTO/Resolution/X86/
H A Dsymtab.ll20 ; CHECK: D------X @fun2@8
21 ; CHECK-NEXT: comdat any @fun2@8
22 $fun2 = comdat any
23 define x86_fastcallcc i32 @fun2(i32 inreg %a, i32 inreg %b) comdat {
/llvm-project-15.0.7/llvm/test/CodeGen/X86/
H A Dprologue-epilogue-remarks.mir7 define void @fun2() noredzone { ret void }
48 name: fun2
54 # CHECK-NEXT: Function: fun2
/llvm-project-15.0.7/clang/test/Sema/
H A Dalias-redefinition.c11 void fun2(void) __attribute((alias("f2"))); // expected-note {{previous definition}}
12 void fun2() {} // expected-error {{redefinition of 'fun2'}} in fun2() function
/llvm-project-15.0.7/clang/test/OpenMP/
H A Dvla_iterator_cache_bug.c9 extern void fun2(int n, int *a, int *b);
16 fun2(n, a, b); in fun1()
/llvm-project-15.0.7/llvm/test/Transforms/CodeExtractor/
H A Dextract-assume.ll10 declare void @fun2(i32) #0
22 call void @fun2(i32 %x)
/llvm-project-15.0.7/llvm/test/CodeGen/AArch64/
H A Dprologue-epilogue-remarks.mir41 name: fun2
47 # CHECK: Function: fun2
/llvm-project-15.0.7/llvm/test/Bitcode/
H A Dblockaddress-users.ll11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress
33 define void @fun2() noinline {
H A Dblockaddress-aggregate-users.ll11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress
35 define void @fun2() noinline {
H A Dblockaddress-expr-users.ll11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress
33 define void @fun2() noinline {
H A Dblockaddress-globalvalue-users.ll11 ; fn, @repro, by accident, when @fun and @fun2 use a global value, @foo,
33 define void @fun2() noinline {
H A Dblockaddress-nested-users.ll11 ; @repro, since @fun and @fun2 both refer to @repro via blockaddress
33 define void @fun2() noinline {
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Dhost-used-device-var.cu106 __host__ __device__ void fun2() { in fun2() function
115 fun2(); in kern1()
H A Dbuiltin-mangled-name.cu26 __host__ __device__ const char *fun2() { in fun2() function
H A Dnoinline.cu16 __attribute__((noinline)) __device__ __host__ void fun2() {} in fun2() function
/llvm-project-15.0.7/llvm/test/MC/AsmParser/
H A Daltmacro_string.s55 .macro fun2 arg macro
59 fun2 <5,6>
/llvm-project-15.0.7/llvm/test/Analysis/CostModel/SystemZ/
H A Dcmp-tofp.ll25 define <2 x double> @fun2(<2 x i64> %val1, <2 x i64> %val2) {
30 ; CHECK: fun2
/llvm-project-15.0.7/clang/test/CodeGenCXX/
H A DPR20038.cpp14 bool fun2() { return (C(), b) && 0; } in fun2() function
/llvm-project-15.0.7/clang/test/PCH/
H A Dstruct.c23 return fun2->very_fun; in get_very_fun()
H A Dstruct.h25 struct Fun2 *fun2; variable
/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Dnoinline.cu9 __attribute__((noinline)) void fun2() { } in fun2() function

123